@@ -56,6 +56,7 @@
 //US static int kphoneInstalled = 0;
 
 using namespace KABC;
+bool AddresseeView::sFullDetailsMode = false;
 
 AddresseeView::AddresseeView( QWidget *parent, const char *name )
   : QTextBrowser( parent, name )
@@ -102,18 +103,24 @@ void AddresseeView::setSource(const QString& n)
 {
     //qDebug("********AddresseeView::setSource %s", n.latin1());
 
-  if ( n.left( 6 ) == "mailto" )
-    ExternalAppHandler::instance()->mailToOneContact( n.mid(7) );
-  else if ( n.left( 7 ) == "phoneto" )
-    ExternalAppHandler::instance()->callByPhone(  n.mid(8) );
-  else if ( n.left( 5 ) == "faxto" )
-    ExternalAppHandler::instance()->callByFax(  n.mid(6) );
-  else if ( n.left( 5 ) == "smsto" )
-    ExternalAppHandler::instance()->callBySMS(  n.mid(6) );
-  else if ( n.left( 7 ) == "pagerto" )
-    ExternalAppHandler::instance()->callByPager(  n.mid(8) );
-  else if ( n.left( 5 ) == "sipto" )
-    ExternalAppHandler::instance()->callBySIP(  n.mid(6) );
+   if ( n == "allDetails" ) {
+       sFullDetailsMode = true;
+       setAddressee( mCurrentContact );
+   } else  if ( n == "notAllDetails" ) {
+       sFullDetailsMode = false;
+       setAddressee( mCurrentContact );
+   } else if ( n.left( 6 ) == "mailto" )
+       ExternalAppHandler::instance()->mailToOneContact( n.mid(7) );
+   else if ( n.left( 7 ) == "phoneto" )
+       ExternalAppHandler::instance()->callByPhone(  n.mid(8) );
+   else if ( n.left( 5 ) == "faxto" )
+       ExternalAppHandler::instance()->callByFax(  n.mid(6) );
+   else if ( n.left( 5 ) == "smsto" )
+       ExternalAppHandler::instance()->callBySMS(  n.mid(6) );
+   else if ( n.left( 7 ) == "pagerto" )
+       ExternalAppHandler::instance()->callByPager(  n.mid(8) );
+   else if ( n.left( 5 ) == "sipto" )
+       ExternalAppHandler::instance()->callBySIP(  n.mid(6) );
 
 }
 void AddresseeView::setAddressee( const KABC::Addressee& mAddressee )
@@ -122,7 +129,7 @@ void AddresseeView::setAddressee( const KABC::Addressee& mAddressee )
   // mAddressee = addr;
   // clear view
   //setText( QString::null );
-
+  mCurrentContact = mAddressee;
   if ( mAddressee.isEmpty() ) {
       setText( QString::null);
       return;
@@ -187,15 +194,7 @@ void AddresseeView::setAddressee( const KABC::Addressee& mAddressee )
     }
   }
 
-  if ( !mAddressee.url().url().isEmpty() ) {
-    dynamicPart += QString(
-      "<tr><td align=\"right\"><b>%1</b></td>"
-      "<td align=\"left\">%2</td></tr>" )
-      .arg( i18n( "Homepage" ) )
-//US      .arg( KStringHandler::tagURLs( mAddressee.url().url() ) );
-      .arg( mAddressee.url().url() );
-    //qDebug("AddresseeView::setAddressee has to be verified.");
-  }
+
 
   KABC::Address::List addresses = mAddressee.addresses();
   KABC::Address::List::ConstIterator addrIt;
@@ -223,17 +222,157 @@ void AddresseeView::setAddressee( const KABC::Addressee& mAddressee )
 
     }
   }
+ 
+ 
+    QString notes;
+    if ( sFullDetailsMode ) {
+        notes = QString(
+                        "<tr><td align=\"right\"><b>%1</b></td>"
+                        "<td align=\"left\"><a href=\"notAllDetails\">%4</a></td></tr>" )
+            .arg( i18n("Details") )
+            .arg( i18n("Hide!") );
+     
+        QString tempX = mAddressee.custom( "KADDRESSBOOK", "X-Gender" );
+        if ( !tempX.isEmpty() ) {
+            if ( tempX == "male" || tempX == "female" ) {
+                notes += QString(
+                                 "<tr><td align=\"right\"><b>%1</b></td>"
+                                 "<td align=\"left\">%2</td></tr>" )
+                    .arg( i18n( "" ) )
+                    .arg( i18n(tempX) );
+            }
+        } 
+
+        
+        tempX =  mAddressee.secrecy().asString();
+        
+        notes += QString(
+                         "<tr><td align=\"right\"><b>%1</b></td>"
+                         "<td align=\"left\">%2</td></tr>" )
+            .arg(  "" )
+            .arg( tempX );
+        
+       
+        tempX = mAddressee.categories().join(" - ");
+        if ( !tempX.isEmpty() ) {
+            notes += QString(
+                             "<tr><td align=\"right\"><b>%1</b></td>"
+                             "<td align=\"left\">%2</td></tr>" )
+                .arg( i18n( "Category" ) )
+                .arg( tempX );
+        } 
+        tempX = mAddressee.custom( "KADDRESSBOOK", "X-Profession" );
+        if ( !tempX.isEmpty() ) {
+            notes += QString(
+                             "<tr><td align=\"right\"><b>%1</b></td>"
+                             "<td align=\"left\">%2</td></tr>" )
+                .arg( i18n( "Profession" ) )
+                .arg( tempX );
+        } 
+        tempX = mAddressee.custom( "KADDRESSBOOK", "X-Office" );
+        if ( !tempX.isEmpty() ) {
+            notes += QString(
+                             "<tr><td align=\"right\"><b>%1</b></td>"
+                             "<td align=\"left\">%2</td></tr>" )
+                .arg( i18n( "Office" ) )
+                .arg( tempX );
+        }
+        tempX = mAddressee.custom( "KADDRESSBOOK", "X-Department" );
+        if ( !tempX.isEmpty() ) {
+            notes += QString(
+                             "<tr><td align=\"right\"><b>%1</b></td>"
+                             "<td align=\"left\">%2</td></tr>" )
+                .arg( i18n( "Department" ) )
+                .arg( tempX );
+        } 
+        
+        tempX = mAddressee.custom( "KADDRESSBOOK", "X-ManagersName" );
+        if ( !tempX.isEmpty() ) {
+            notes += QString(
+                             "<tr><td align=\"right\"><b>%1</b></td>"
+                             "<td align=\"left\">%2</td></tr>" )
+                .arg( i18n( "Manager" ) )
+                .arg( tempX );
+        } 
+        tempX = mAddressee.custom( "KADDRESSBOOK", "X-AssistantsName" );
+        if ( !tempX.isEmpty() ) {
+            notes += QString(
+                             "<tr><td align=\"right\"><b>%1</b></td>"
+                             "<td align=\"left\">%2</td></tr>" )
+                .arg( i18n( "Assistant" ) )
+                .arg( tempX );
+        } 
+        if ( !mAddressee.url().url().isEmpty() ) {
+            notes += QString(
+                             "<tr><td align=\"right\"><b>%1</b></td>"
+                             "<td align=\"left\">%2</td></tr>" )
+                .arg( i18n( "Homepage" ) )
+                .arg( mAddressee.url().url() );
+        }
+        tempX = mAddressee.nickName();
+        if ( !tempX.isEmpty() ) {
+            notes += QString(
+                             "<tr><td align=\"right\"><b>%1</b></td>"
+                             "<td align=\"left\">%2</td></tr>" )
+                .arg( i18n( "Nickname" ) )
+                .arg( tempX );
+        }
+        tempX = mAddressee.custom( "KADDRESSBOOK", "X-IMAddress" );
+        if ( !tempX.isEmpty() ) {
+            notes += QString(
+                             "<tr><td align=\"right\"><b>%1</b></td>"
+                             "<td align=\"left\">%2</td></tr>" )
+                .arg( i18n( "Messanger" ) )
+                .arg( tempX );
+        }
+       
+        tempX = mAddressee.custom( "KADDRESSBOOK", "X-Anniversary" );
+        if ( !tempX.isEmpty() ) {
+            QDate dt = KGlobal::locale()->readDate( tempX, "%Y-%m-%d");
+            if ( dt.isValid () ) {
+                tempX = KGlobal::locale()->formatDate(dt, true);
+                notes += QString(
+                                 "<tr><td align=\"right\"><b>%1</b></td>"
+                                 "<td align=\"left\">%2</td></tr>" )
+                    .arg( i18n( "Anniversary" ) )
+                    .arg( tempX );
+            }
+        } 
+        tempX = mAddressee.custom( "KADDRESSBOOK", "X-SpousesName" );
+        if ( !tempX.isEmpty() ) {
+            notes += QString(
+                             "<tr><td align=\"right\"><b>%1</b></td>"
+                             "<td align=\"left\">%2</td></tr>" )
+                .arg( i18n( "Spouse" ) )
+                .arg( tempX );
+        } 
+        tempX = mAddressee.custom( "KADDRESSBOOK", "X-Children" );
+        if ( !tempX.isEmpty() ) {
+            notes += QString(
+                             "<tr><td align=\"right\"><b>%1</b></td>"
+                             "<td align=\"left\">%2</td></tr>" )
+                .arg( i18n( "Children" ) )
+                .arg( tempX );
+        } 
+       
+      if (  !mAddressee.note().isEmpty() ) {
+          notes += QString(
+                          "<tr>"
+                          "<td align=\"right\" valign=\"top\"><b>%1</b></td>"  // note label
+                          "<td align=\"left\">%2</td>"  // note
+                          "</tr>" ).arg( i18n( "Notes" ) )
+              //US      .arg( mAddressee.note().replace( '\n', "<br>" ) );
+              .arg( mAddressee.note().replace( QRegExp("\n"), "<br>" ) );
+          //qDebug("AddresseeView::setAddressee has to be verified.");
+      }
+  } else {
+      notes = QString(
+            "<tr><td align=\"right\"><b>%1</b></td>"
+           "<td align=\"left\"><a href=\"allDetails\">%4</a></td></tr>" )
+          .arg( i18n("Details") )
+          .arg( i18n("Show!") );
+
 
-  QString notes;
-  if ( !mAddressee.note().isEmpty() ) {
-    notes = QString(
-      "<tr>"
-      "<td align=\"right\" valign=\"top\"><b>%1</b></td>"  // note label
-      "<td align=\"left\">%2</td>"  // note
-      "</tr>" ).arg( i18n( "Notes" ) )
-//US      .arg( mAddressee.note().replace( '\n', "<br>" ) );
-      .arg( mAddressee.note().replace( QRegExp("\n"), "<br>" ) );
-    //qDebug("AddresseeView::setAddressee has to be verified.");
   }
 
   QString aRole = "";
