@@ -105,10 +105,7 @@ KOPrefsDialog::~KOPrefsDialog()
 }
 void KOPrefsDialog::setupGlobalTab() 
 {
-   QFrame *topFrame = addPage(i18n("Global"),0,0);
-   kdelibcfg = new KDEPIMConfigWidget(  KPimGlobalPrefs::instance(), topFrame, "KCMKdeLibConfig" );
-   QVBoxLayout *topLayout = new QVBoxLayout(topFrame);
-   topLayout->addWidget( kdelibcfg );
+   
 
 
 } 
@@ -228,14 +225,12 @@ void KOPrefsDialog::usrReadConfig()
   mNameEdit->setText(KOPrefs::instance()->mName);
   mEmailEdit->setText(KOPrefs::instance()->mEmail);
   //mCodecEdit->setText(KOPrefs::instance()->mSendCodec);
-  kdelibcfg->readConfig();
 }
 void KOPrefsDialog::usrWriteConfig()
 {
     KOPrefs::instance()->mName = mNameEdit->text();
     KOPrefs::instance()->mEmail = mEmailEdit->text();
     //KOPrefs::instance()->mSendCodec = mCodecEdit->text();
-    kdelibcfg->writeConfig();
  
     
 }
