@@ -77,8 +77,6 @@ JournalEntry::JournalEntry(Calendar *calendar,QWidget *parent) :
   iconp = SmallIcon("1updownarrow");
   toggleJournal->setPixmap (iconp ) ;
   QLabel* textLabel = new QLabel(" "+i18n("Title: "),vb);
-  vb->setStretchFactor (textLabel,1);
-  vb->setStretchFactor( toggleJournal, 1 );
   mTitle = new KOLocationBox(TRUE, vb, 30);
   mTitle->setSizePolicy( QSizePolicy(  QSizePolicy::Preferred ,QSizePolicy::Fixed  ,FALSE) );
   mCalendarBox = new QComboBox(vb);
@@ -109,7 +107,10 @@ JournalEntry::JournalEntry(Calendar *calendar,QWidget *parent) :
   loadTemplate->setPixmap (iconp ) ;
   loadTemplate->setFixedSize(  size, size );
   saveTemplate->setFixedSize(  size, size );
-  toggleJournal->setFixedSize( size  , size );
+  int widwid = size;
+  if ( QApplication::desktop()->width() < 320 )
+      widwid = size/2+1;
+  toggleJournal->setFixedSize( widwid , size );
   mTitle->setFixedHeight( size+4);
   mCalendarBox->setFixedHeight( size+4);
   mEditor = new KTextEdit(this);
@@ -249,7 +250,9 @@ void JournalEntry::fillCalendar( int setToID )
 }
 
 void JournalEntry::toggleShowJournal()
-{ 
+{  
+    if ( mEditor->text().isEmpty() && mTitle->currentText ().isEmpty() )
+        return;
     if (!mEditor->text().isEmpty() || !mTitle->currentText ().isEmpty())
         flushEntry();
     if ( showOnlyMode )
