@@ -87,7 +87,10 @@ MarcusBains::~MarcusBains()
 {
     //delete minutes;
 }
-
+void MarcusBains::hideMe()
+{
+    hide(); mTimeBox->hide();
+}
 int MarcusBains::todayColumn()
 {
     QDate currentDate = QDate::currentDate();
@@ -106,7 +109,8 @@ int MarcusBains::todayColumn()
 }
 void MarcusBains::updateLoc()
 {
-    updateLocation();
+    if ( !agenda->invalidPixmap() )
+        updateLocation();
 }
 void MarcusBains::updateLocation(bool recalculate)
 {
@@ -372,6 +376,7 @@ void KOAgenda::changeColumns(int columns)
     clear();
     mColumns = columns;
     computeSizes();
+    if(mMarcusBains) mMarcusBains->hideMe();
 }
 
 /*
@@ -437,12 +442,16 @@ void KOAgenda::categoryChanged(Incidence * inc)
         }
     }
 }
+bool KOAgenda::invalidPixmap()
+{
+    return mInvalidPixmap;
+}
 bool KOAgenda::eventFilter_mouse(QObject *object, QMouseEvent *me)
 {
 
     if ( mInvalidPixmap ) {
         mInvalidPixmap = false;
-        qDebug("KO: Upsizing Pixmaps ");
+        qDebug("KO: efm Upsizing Pixmaps %s", QDateTime::currentDateTime().toString().latin1());
         computeSizes();
         emit updateViewSignal();
         return true;
@@ -1277,11 +1286,12 @@ void KOAgenda::drawContents(QPainter* p, int cx, int cy, int cw, int ch)
 
     if ( mInvalidPixmap ) {
         mInvalidPixmap = false;
-        qDebug("KO: Upsizing Pixmaps ");
+        qDebug("KO: dc Upsizing Pixmaps %s", QDateTime::currentDateTime().toString().latin1());
         computeSizes();
         emit updateViewSignal();
         return;
-    }
+    } 
+    //qDebug("KOAgenda::drawContents %s", QDateTime::currentDateTime().toString().latin1());
     if ( ! mAllDayMode ) {
         // currently not working for
    
