@@ -603,7 +603,7 @@ void KOAgendaView::slotIdleTimeout()
         startIdleTimeout();
         return;
     }
-    qDebug("KO: Downsizing Pixmaps ");
+    qDebug("KO: Downsizing Pixmaps %s",QDateTime::currentDateTime().toString().latin1());
     mAgenda->shrinkPixmap();
     mAllDayAgenda->shrinkPixmap();
     KOAgendaItem::paintPix()->resize( 20,20);
