@@ -518,17 +518,17 @@ RecurrenceRangeWidget::RecurrenceRangeWidget( QWidget *parent,
   mStartDateLabel = new QLabel( i18n("Begin on:"), rangeBox );
   rangeLayout->addWidget( mStartDateLabel );
 
-  QButtonGroup *rangeButtonGroup = new QButtonGroup;
+  mRangeButtonGroup = new QButtonGroup;
 
   mNoEndDateButton = new QRadioButton( i18n("No ending date"), rangeBox );
-  rangeButtonGroup->insert( mNoEndDateButton );
+  mRangeButtonGroup->insert( mNoEndDateButton );
   rangeLayout->addWidget( mNoEndDateButton );
 
   QBoxLayout *durationLayout = new QHBoxLayout( rangeLayout );
   durationLayout->setSpacing( KDialog::spacingHint() );
 
   mEndDurationButton = new QRadioButton( i18n("End after"), rangeBox );
-  rangeButtonGroup->insert( mEndDurationButton );
+  mRangeButtonGroup->insert( mEndDurationButton );
   durationLayout->addWidget( mEndDurationButton );
 
   mEndDurationEdit = new QSpinBox( 1, 9999, 1, rangeBox );
@@ -541,7 +541,7 @@ RecurrenceRangeWidget::RecurrenceRangeWidget( QWidget *parent,
   endDateLayout->setSpacing( KDialog::spacingHint() );
 
   mEndDateButton = new QRadioButton( i18n("End by:"), rangeBox );
-  rangeButtonGroup->insert( mEndDateButton );
+  mRangeButtonGroup->insert( mEndDateButton );
   endDateLayout->addWidget( mEndDateButton );
 
   mEndDateEdit = new KDateEdit( rangeBox );
@@ -557,6 +557,10 @@ RecurrenceRangeWidget::RecurrenceRangeWidget( QWidget *parent,
            SLOT( showCurrentRange() ) );
 }
 
+RecurrenceRangeWidget::~RecurrenceRangeWidget()
+{
+    delete mRangeButtonGroup;
+}
 void RecurrenceRangeWidget::setDefaults( const QDateTime &from  )
 {
   mNoEndDateButton->setChecked( true );
