@@ -29,6 +29,7 @@
 #include <qdialog.h>
 #include <qtextstream.h>
 #include <qtextcodec.h>
+#include <qwhatsthis.h>
 
 
 #include <libkcal/calfilter.h>
@@ -251,17 +252,20 @@ void KOCalEditView::readConfig()
     mainLayout->addWidget( addButT,0,0 );
     addButT->setText( "D");
     connect(addButT,SIGNAL(clicked()),SLOT(defaultInfo()));
+    QWhatsThis::add( addButT, i18n("Please choose the <b>default calendar</b> in this column. Newly created or imported items are added to the default calendar.") );
     //addBut->setPixmap ( SmallIcon("greenhook16"));
     QPushButton *addBut = new QPushButton ( mw );
     addBut->setFocusPolicy(NoFocus); 
     mainLayout->addWidget( addBut,0,++ii );
     addBut->setPixmap ( SmallIcon("eye"));
+    QWhatsThis::add( addBut, i18n("In this column you can <b>set a calendar to be visible</b>. If a calendar is not visible its entries are not displayed in the views. You can add items to it and it is loaded/saved as usual.") );
     connect(addBut,SIGNAL(clicked()),SLOT(enableAll()));
     int max = addBut->sizeHint().height();
     addBut->setMaximumWidth( max );
     addButT->setFixedSize( QSize( max, max ) );
     QLabel* lab = new QLabel (i18n(" Calendar \n Resource "), mw );
     mainLayout->addWidget( lab,0,++ii ); 
+    QWhatsThis::add( lab, i18n("In this column you can see the <b>name of the calendar</b>. If you click on the name button you will get an information box about the loaded calendar file. If the file was not loaded at startup you can try to load it here again.") );
     //lab = new QLabel ( i18n(" "), mw );
     //mainLayout->addWidget( lab,0,++ii );
     //lab->setFixedWidth( 1 );
@@ -269,6 +273,7 @@ void KOCalEditView::readConfig()
     addBut->setFocusPolicy(NoFocus); 
     mainLayout->addWidget( addBut,0,++ii );
     addBut->setPixmap ( SmallIcon("bell"));
+    QWhatsThis::add( addBut, i18n("In this column you can <b>disable the alarms of a calendar all together</b>. The alarm data in the calendar itself is not changed, the alarms are marked internally as \"do not use\". Useful if you load a calendar of another person but do not want to get notified about alarms of that person.") );
     connect(addBut,SIGNAL(clicked()),SLOT(enableAlarm()));
     addBut->setMaximumWidth( addBut->sizeHint().height() );
 
@@ -276,6 +281,7 @@ void KOCalEditView::readConfig()
     addBut->setFocusPolicy(NoFocus); 
     mainLayout->addWidget( addBut,0,++ii );
     addBut->setPixmap ( SmallIcon("pencil"));
+    QWhatsThis::add( addBut, i18n("In this column you can <b>set a calendar and all entries of the calendar to read only</b>. If a calendar is readonly the entries cannot be edited and no items can be added to the calendar. If you change a setting of a calendar to readonly in this column all data will be saved because the data of a readonly calendar is not saved later.") );
     connect(addBut,SIGNAL(clicked()),SLOT(disableRO()));
     addBut->setMaximumWidth( addBut->sizeHint().height() );
     lab = new QLabel ( "", mw );
@@ -286,7 +292,7 @@ void KOCalEditView::readConfig()
     mainLayout->addWidget( addBut,0,++ii );
     addBut->setPixmap ( SmallIcon("plus"));
     connect(addBut,SIGNAL(clicked()),SLOT(addCal()));
-
+    QWhatsThis::add( addBut, i18n("Click this button to <b>add a calendar</b>. You can add an existing calendar file or you can add a new calendar and KO/Pi creates a new empty calendar file for you.") );
     lab = new QLabel ( " ", mw );
     mainLayout->addWidget( lab,0,++ii );
 
