@@ -1285,6 +1285,8 @@ void KOListViewListView::keyPressEvent ( QKeyEvent *e)
                     if ( cn ) {
                         setCurrentItem ( cn );
                         ensureItemVisible ( cn );
+                    } else {
+                        emit currentChanged( ci );
                     }
                 }
             }
