@@ -414,7 +414,7 @@ void KOTodoListView::keyPressEvent ( QKeyEvent * e )
     if (! e->isAutoRepeat() )
         mFlagKeyPressed = true;
     QListViewItem* cn;
-    if ( e->key() == Qt::Key_Return || e->key() == Qt::Key_Enter ) {
+    if ( (e->key() == Qt::Key_Return || e->key() == Qt::Key_Enter) && mName != "todolistsmall") {
         cn = currentItem();
         if ( cn ) {
             KOTodoViewItem* ci = (KOTodoViewItem*)( cn ); 
@@ -483,6 +483,7 @@ KOQuickTodo::KOQuickTodo(QWidget *parent) :
   QLineEdit(parent)
 {
   setText(i18n("Click to add new Todo"));
+  setFocusPolicy ( QWidget::ClickFocus );
 }
 
 void KOQuickTodo::focusInEvent(QFocusEvent *ev)
@@ -502,7 +503,8 @@ void KOQuickTodo::focusOutEvent(QFocusEvent *ev)
 
 KOTodoView::KOTodoView(Calendar *calendar,QWidget* parent,const char* name) :
   KOrg::BaseView(calendar,parent,name)
-{
+{ 
+    mActiveItem = 0;
     mCategoryPopupMenu = 0;
     mPendingUpdateBeforeRepaint = false;
     isFlatDisplay = false;
@@ -551,7 +553,21 @@ KOTodoView::KOTodoView(Calendar *calendar,QWidget* parent,const char* name) :
   allclose->setFixedHeight(fixhei );
   s_run->setFixedHeight(fixhei );
   mNewSubBut->setFixedHeight(fixhei );
+
+  flat->setFocusPolicy( NoFocus );
+  s_done->setFocusPolicy( NoFocus );
+  allopen->setFocusPolicy( NoFocus );
+  allclose->setFocusPolicy( NoFocus );
+  s_run->setFocusPolicy( NoFocus );
+  mNewSubBut->setFocusPolicy( NoFocus );
   
+  QWhatsThis::add( flat, i18n("Click this button to display all todos in a <b>flat</b> hierarchy" ) );
+  QWhatsThis::add( allopen, i18n("Click this button to display all todos <b>openend</b>" ) );
+  QWhatsThis::add( allclose, i18n("Click this button to display all todos <b>closed</b>" ) );
+  QWhatsThis::add( s_run, i18n("Click this button to toggle show/hide <b>running</b> todos" ) );
+  QWhatsThis::add( mNewSubBut, i18n("Click this button to add a new subtodo to the currently selected todo" ) );
+  QWhatsThis::add( s_done, i18n("Click this button to toggle show/hide <b>completed</b> todos" ) );
+
   quickLayout->addWidget( mNewSubBut );
   quickLayout->addWidget( s_done );
   quickLayout->addWidget( s_run );
@@ -807,28 +823,38 @@ void  KOTodoView::paintEvent(QPaintEvent * pevent)
     KOrg::BaseView::paintEvent( pevent);
 }
 
+void KOTodoView::clearList( bool saveCurrentItem ) // default true 
+{
+   if ( mTodoListView->childCount() ) {
+       if ( saveCurrentItem )
+           storeCurrentItem();
+       mTodoListView->clear();
+       mTodoMap.clear();
+    }
+}
 void KOTodoView::updateView()
 {
+    mActiveItem = 0;
     pendingSubtodo = 0;
     if ( mBlockUpdate ) {
         return;
     }
     if ( !isVisible() ) {
-       mPendingUpdateBeforeRepaint = true;
-       return;
+        clearList ();
+        mPendingUpdateBeforeRepaint = true;
+        return;
     }
     //qDebug("KOTodoView::updateView() %x", this);
     if ( isFlatDisplay ) {
         displayAllFlat();
         return;
     }
-    storeCurrentItem();
     //qDebug("update ");
 //  kdDebug() << "KOTodoView::updateView()" << endl;
     QFont fo = KOPrefs::instance()->mTodoViewFont;
    
-
-    mTodoListView->clear();
+    clearList ();
+   
     if ( mName == "todolistsmall" ) {
         if ( KOPrefs::instance()->mTodoViewUsesSmallFont ) {
             int ps = fo.pointSize() -2;
@@ -864,7 +890,6 @@ void KOTodoView::updateView()
   // Put for each Event a KOTodoViewItem in the list view. Don't rely on a
   // specific order of events. That means that we have to generate parent items
   // recursively for proper hierarchical display of Todos.
-  mTodoMap.clear();
   Todo *todo;
   todo = todoList.first();// todo; todo = todoList.next()) {
   while ( todo ) {
@@ -974,7 +999,8 @@ void KOTodoView::resetCurrentItem()
         }
     }
     processSelectionChange(); 
-    QTimer::singleShot( 100, this, SLOT ( resetFocusToList() ));
+    if ( mName != "todolistsmall" )
+        QTimer::singleShot( 100, this, SLOT ( resetFocusToList() ));
 }
 void KOTodoView::resetFocusToList()
 {
@@ -1100,12 +1126,14 @@ void KOTodoView::printPreview(CalPrinter *calPrinter, const QDate &fd,
 
 void KOTodoView::editItem(QListViewItem *item )
 {
-  emit editTodoSignal(((KOTodoViewItem *)item)->todo());
+    if ( item ) 
+        emit editTodoSignal(((KOTodoViewItem *)item)->todo());
 }
 
 void KOTodoView::showItem(QListViewItem *item,const QPoint &,int)
 {
-  emit showTodoSignal(((KOTodoViewItem *)item)->todo());
+    if ( item ) 
+        emit showTodoSignal(((KOTodoViewItem *)item)->todo());
 }
 
 void KOTodoView::popupMenu(QListViewItem *item,const QPoint &p,int column)
@@ -1357,7 +1385,7 @@ void KOTodoView::toggleRunningItem()
             tp.setGeometry( xx,yy,wid,hei );
         }
         tp.exec();
-        mActiveItem->construct();
+        updateTodo ( t, KOGlobals::EVENTEDITED );
     } else {
         KOStartTodoPrefs tp ( t->summary(), this );
         if (QApplication::desktop()->width() <= 800 ){
@@ -1374,7 +1402,7 @@ void KOTodoView::toggleRunningItem()
             updateView();
         } else {
             t->setRunning( true );
-            mActiveItem->construct();
+            updateTodo ( t, KOGlobals::EVENTEDITED );
         }
     }
 }
@@ -1505,16 +1533,16 @@ void  KOTodoView::setOpen( QListViewItem* item, bool setOpenI)
 
 void KOTodoView::displayAllFlat()
 {
-    storeCurrentItem();
+  
+    mActiveItem = 0;
     pendingSubtodo = 0;
     if ( mBlockUpdate ) {
         return;
     }
+    clearList ();
     mPopupMenu->setItemChecked( 8,true );
     isFlatDisplay = true;
     QPtrList<Todo> todoList = calendar()->todos();
-    mTodoMap.clear();
-    mTodoListView->clear();
     Todo *todo;   
     for(todo = todoList.first(); todo; todo = todoList.next()) {
         if ( checkTodo( todo ) ) {
@@ -1692,16 +1720,14 @@ void KOTodoView::keyPressEvent ( QKeyEvent * e )
                     
                 }
             }
-            e->accept();
-        
+            e->accept();   
         }
-        
     }
-    
 }
+
 void KOTodoView::updateTodo( Todo * t, int type )
 {
-    if  ( mBlockUpdate)
+    if  ( mBlockUpdate )
         return;
 
     QMap<Todo *,KOTodoViewItem *>::ConstIterator itemIterator;
