@@ -489,14 +489,14 @@ bool KOWhatsNextView::appendEvent(Incidence *ev, bool reply, bool notRed, bool a
     bool ok = true; 
     if ( reply ) {
         noc = ev->getNextOccurence( cdt, &ok );
-        if (! ok && ev->type() == "Event")
+        if (! ok && ev->typeID() == eventID)
             return false;
     }
     bool bDay = false;
     if ( ev->isBirthday()  || ev->isAnniversary()  )
         bDay = true;
     tempText += "<tr><td><b>";
-    if (ev->type()=="Event") {
+    if (ev->typeID() == eventID ) {
         if (reply)  {
             if (!ev->doesFloat())
                 tempText += KGlobal::locale()->formatDateTime( noc , KOPrefs::instance()->mShortDateInViewer) +": ";
@@ -507,7 +507,7 @@ bool KOWhatsNextView::appendEvent(Incidence *ev, bool reply, bool notRed, bool a
             if (!ev->doesFloat()) {
                 Event *event = static_cast<Event *>(ev);
                 QDateTime st,end;
-                if ( event->recurrence()->doesRecur() ) {
+                if ( event->doesRecur() ) {
                     QDate  recDate= mEventDate;
                     int days =  event->dtStart().date().daysTo (event->dtEnd().date()  );
                     while ( ! event->recursOn(  recDate ) ) {
@@ -529,6 +529,8 @@ bool KOWhatsNextView::appendEvent(Incidence *ev, bool reply, bool notRed, bool a
                     dateText = "++:++-";
                 else
                     dateText =  event->dtStartTimeStr() + "-";
+                if ( KOPrefs::instance()->mWhatsNextTime2Lines )
+                    dateText += " "; 
                 if ( end.date() > mEventDate ) 
                     dateText += "++:++";
                 else
@@ -556,7 +558,17 @@ bool KOWhatsNextView::appendEvent(Incidence *ev, bool reply, bool notRed, bool a
                     else
                         tempText += "<font color=\"#00B0000\">" + i18n("Anniversary")+":</font>";
                 } else {
-                    tempText += i18n("Allday:");
+                    if ( ((Event*)ev)->isMultiDay() ) {
+                        QString dfs = KGlobal::locale()->dateFormatShort();
+                        KGlobal::locale()->setDateFormatShort("%d.%b");
+                        tempText +=KGlobal::locale()->formatDate(((Event*)ev)->dtStart().date(), true, KLocale::Userdefined) + "-";
+                        if ( KOPrefs::instance()->mWhatsNextTime2Lines )
+                            tempText += " ";
+                        tempText +=KGlobal::locale()->formatDate(((Event*)ev)->dtEnd().date(), true, KLocale::Userdefined);
+                        KGlobal::locale()->setDateFormatShort(dfs);
+                    } else {
+                        tempText += " " ;//i18n("Allday:");
+                    }
                 }
 
             }
@@ -564,6 +576,8 @@ bool KOWhatsNextView::appendEvent(Incidence *ev, bool reply, bool notRed, bool a
     } else {
         mTodos.append( ev );
         tempText += i18n("ToDo:"); 
+        if ( KOPrefs::instance()->mWhatsNextTime2Lines )
+            tempText += " "; 
         if (reply)  {
             tempText += " "; 
             if ( noc != cdt ) {
@@ -595,7 +609,7 @@ bool KOWhatsNextView::appendEvent(Incidence *ev, bool reply, bool notRed, bool a
         needClose =true;
 
     }
-    if ( ev->isAlarmEnabled() ) { 
+    if ( ev->isAlarmEnabled() && ev->alarmEnabled()) { 
         if ( !needClose)
             tempText +="[";
         tempText += "a";
@@ -608,7 +622,7 @@ bool KOWhatsNextView::appendEvent(Incidence *ev, bool reply, bool notRed, bool a
         tempText += "i";
         needClose =true;
     }
-    if ( ev->recurrence()->doesRecur() ) {
+    if ( ev->doesRecur() ) {
         if ( !needClose)
             tempText +="[";
         tempText += "r";
@@ -620,8 +634,8 @@ bool KOWhatsNextView::appendEvent(Incidence *ev, bool reply, bool notRed, bool a
     if ( ev->cancelled() ) 
         tempText += "</font>";
     tempText += "<a ";
-    if (ev->type()=="Event") tempText += "href=\"event:";
-    if (ev->type()=="Todo") tempText += "href=\"todo:";
+    if (ev->typeID() == eventID ) tempText += "href=\"event:";
+    if (ev->typeID() == todoID ) tempText += "href=\"todo:";
     tempText += ev->uid() + "\">";
     if ( ev->summary().length() > 0 )
         tempText += ev->summary();
@@ -631,7 +645,7 @@ bool KOWhatsNextView::appendEvent(Incidence *ev, bool reply, bool notRed, bool a
         noc = ev->getNextOccurence( cdt.addDays(-1), &ok );
         if ( ok ) {
             int years = 0;
-            if ( ev->type() =="Todo" ) {
+            if ( ev->typeID() == todoID  ) {
                 years = noc.date().year() -((Todo*)ev)->dtDue().date().year();
             } else
                 years = noc.date().year() - ev->dtStart().date().year();
@@ -669,7 +683,7 @@ bool KOWhatsNextView::appendTodo(Incidence *ev, QString ind , bool isSub )
         needClose =true;
 
     }
-    if ( ev->isAlarmEnabled() ) { 
+    if ( ev->isAlarmEnabled() && ev->alarmEnabled() ) { 
         if ( !needClose)
             mText +="[";
         mText += "a";
