@@ -256,7 +256,7 @@ void CalendarLocal::close()
 
   mEventList.setAutoDelete( true );
   mTodoList.setAutoDelete( true );
-  mJournalList.setAutoDelete( false );
+  mJournalList.setAutoDelete( true );
 
   mEventList.clear();
   mTodoList.clear();
@@ -268,7 +268,7 @@ void CalendarLocal::close()
 
   setModified( false );
 }
-    
+
 bool CalendarLocal::addAnniversaryNoDup( Event *event )
 {
     QString cat;
@@ -327,8 +327,7 @@ bool CalendarLocal::addEvent( Event *event )
 
 void CalendarLocal::deleteEvent( Event *event )
 {
-    if ( mUndoIncidence ) delete mUndoIncidence;
-    mUndoIncidence = event->clone();
+    clearUndo(event);
     if ( mEventList.removeRef( event ) ) {
         setModified( true );
     }
@@ -382,9 +381,8 @@ bool CalendarLocal::addTodo( Todo *todo )
 void CalendarLocal::deleteTodo( Todo *todo )
 {
   // Handle orphaned children
-    if ( mUndoIncidence ) delete mUndoIncidence;
     removeRelations( todo );
-    mUndoIncidence = todo->clone();
+    clearUndo(todo);
 
   if ( mTodoList.removeRef( todo ) ) {
     setModified( true );
@@ -886,9 +884,7 @@ bool CalendarLocal::addJournal(Journal *journal)
 
 void CalendarLocal::deleteJournal( Journal *journal )
 {
-    if ( mUndoIncidence ) delete mUndoIncidence;
-    mUndoIncidence = journal->clone();
-    mUndoIncidence->setSummary( mUndoIncidence->description().left(25));
+    clearUndo(journal);
   if ( mJournalList.removeRef(journal) ) {
     setModified( true );
   }
@@ -967,8 +963,7 @@ void CalendarLocal::setCalendarRemove( int id )
         }
     }
 
-    if ( mUndoIncidence ) delete mUndoIncidence;
-    mUndoIncidence = 0;
+    clearUndo(0);
 
 }
 
