@@ -56,10 +56,17 @@ Incidence::Incidence( const Incidence &i ) : IncidenceBase( i )
   mCategories = i.mCategories;
 //  Incidence *mRelatedTo;          Incidence *mRelatedTo;
   mRelatedTo = 0;
-  mRelatedToUid = i.mRelatedToUid;
+  mRelatedToUid = i.mRelatedToUid; 
 //  QPtrList<Incidence> mRelations;    QPtrList<Incidence> mRelations;
   mExDates = i.mExDates;
-  mAttachments = i.mAttachments;
+  QPtrListIterator<Attachment> itat( i.mAttachments );
+  Attachment *at;
+  while( (at = itat.current()) ) {
+      Attachment *a = new Attachment( *at );
+      mAttachments.append( a );
+      ++itat;
+  }
+  mAttachments.setAutoDelete( true );
   mResources = i.mResources;
   mSecrecy = i.mSecrecy;
   mPriority = i.mPriority;
@@ -491,7 +498,11 @@ void Incidence::setRelatedToUid(const QString &relatedToUid)
   if (mReadOnly) return;
   mRelatedToUid = relatedToUid;
 }
-
+void Incidence::clearRelations()
+{
+    mRelatedTo = 0;
+    mRelations.clear();
+}
 QString Incidence::relatedToUid() const
 {
   return mRelatedToUid;
@@ -753,6 +764,7 @@ Recurrence *Incidence::recurrence()
     if ( ! mRecurrence ) {
         mRecurrence = new Recurrence(this);
         mRecurrence->setRecurStart( dtStart() );
+        mRecurrence->setRecurReadOnly( isReadOnly());
         //qDebug("creating new recurence ");
         //abort();
     }
