@@ -823,7 +823,7 @@ QString SharpFormat::getEventString( Event* event )
         
         if ( rec->endDate().isValid() ) { // 15 + 16
             list.append( "1" );
-            list.append( dtToString( rec->endDate()) );
+            list.append( dtToString( rec->endDate(), false ) );
         } else {
             list.append( "0" );
             list.append( "20991231T000000" );
