@@ -25,7 +25,7 @@
 Enhanced Version of the file for platform independent KDE tools.
 Copyright (c) 2004 Ulf Schenk
 
-$Id: kdepimconfigwidget.cpp,v 1.25 2005/04/21 17:43:51 zautrix Exp $
+$Id: kdepimconfigwidget.cpp,v 1.29 2005/07/27 16:04:27 zautrix Exp $
 */
 
 #include <qlayout.h>
@@ -89,6 +89,7 @@ $Id: kdepimconfigwidget.cpp,v 1.25 2005/04/21 17:43:51 zautrix Exp $
 #include <kmessagebox.h>
 
 
+
 KDEPIMConfigWidget::KDEPIMConfigWidget(KPimGlobalPrefs *prefs, QWidget *parent, const char *name )
   : KPrefsWidget(prefs, parent, name )
 {
@@ -135,6 +136,7 @@ void KDEPIMConfigWidget::setupBackupTab()
                       &(KPimGlobalPrefs::instance()->mBackupUseDefaultDir),bupFrame);
     bupLayout->addWidget((QWidget*)sb->checkBox());
     mBackupUrl = new KURLRequester( bupFrame );
+    mBackupUrl->setPathIsDir();
     mBackupUrl->setURL( KGlobalSettings::backupDataDir() );
     QObject::connect ( sb->checkBox(), SIGNAL (toggled ( bool ) ), mBackupUrl ,SLOT ( setDisabled( bool ) ) );
     bupLayout->addWidget( mBackupUrl );
@@ -176,10 +178,12 @@ void KDEPIMConfigWidget::setupStoreTab()
     topLayout->addWidget( (QWidget* )holidayColor->button());
 
 
-    QVBox *storePage = new QVBox( this );
+    QVBox *storePage = new QVBox( this ); 
+    if (  QApplication::desktop()->height() > 240 )
     new QLabel( i18n("Your current storage dir is:\n%1\nYour mail is stored in:\n(storagedir)/apps/kopiemail/localmail").arg(KGlobal::dirs()->localkdedir()), storePage  );
     new QLabel( i18n("<b>New data storage dir:</b>"), storePage );
     mStoreUrl = new KURLRequester( storePage );
+    mStoreUrl->setPathIsDir();
     mStoreUrl->setURL( KGlobal::dirs()->localkdedir() );
 #ifdef DESKTOP_VERSION     
     QString confFile = qApp->applicationDirPath ()+ "/.microkdehome" ;
@@ -194,7 +198,7 @@ void KDEPIMConfigWidget::setupStoreTab()
         }
     }
                
-#endif
+#endif 
     new QLabel( i18n("New dirs are created automatically"), storePage  );
     QHBox *bb = new QHBox( storePage );
     QPushButton * pb;
@@ -210,8 +214,14 @@ void KDEPIMConfigWidget::setupStoreTab()
     connect(pb, SIGNAL( clicked() ), this, SLOT ( setLocalStore() ) );
 #endif
     new QLabel( i18n("<b>New settings are used\nafter a restart</b>"), storePage );
-    new QLabel( i18n("Settings are stored in\n%1").arg(QDir::homeDirPath() + "/.microkdehome" ), storePage  );
+    mDataStoragePath = new QLabel( i18n("Settings are stored in\n%1").arg(QDir::homeDirPath() + "/.microkdehome" ), storePage  );
     tabWidget->addTab( storePage, i18n( "Data storage path" ) );
+
+#ifdef DESKTOP_VERSION  
+      if ( mStoreUrl->url().startsWith( "LOCAL:" ) ) {
+	mDataStoragePath->setText( i18n("Settings are stored in\n%1").arg( qApp->applicationDirPath ()+"/.microkdehome" ));
+      }
+#endif
 }
 void KDEPIMConfigWidget::setLocalStore()
 {
@@ -227,6 +237,17 @@ void KDEPIMConfigWidget::setStandardStore()
 }
 void KDEPIMConfigWidget::saveStoreSettings()
 {
+#ifdef DESKTOP_VERSION
+        if ( !mStoreUrl->url().startsWith( "LOCAL:" ) ) {
+            QString file = qApp->applicationDirPath ()+"/.microkdehome";
+            QFileInfo fi ( file );
+            if ( fi.exists() ) {
+                bool res = QFile::remove( file );
+                if ( ! res )
+                    KMessageBox::information( this, i18n("ERROR: Cannot remove file\n%1\nPlease remove it manually.").arg( file ));
+            }
+        }
+#endif
     if ( !mStoreUrl->url().isEmpty() ) {
         QString path = QDir::homeDirPath();
         QString url = mStoreUrl->url();
@@ -240,6 +261,7 @@ void KDEPIMConfigWidget::saveStoreSettings()
         cfg.writeEntry( "MICROKDEHOME", url ); 
         qDebug("cfg.writeEntry( MICROKDEHOME, %s  ", url.latin1());
         cfg.sync();
+	mDataStoragePath->setText( i18n("Settings are stored in\n%1").arg( path+"/.microkdehome" ));
     } else {
         mStoreUrl->setURL(  QDir::homeDirPath() + "/kdepim"  );
         saveStoreSettings();
@@ -290,32 +312,35 @@ void KDEPIMConfigWidget::setupExternalAppTab()
   mParameters = new QLineEdit(mExternalAppGroupBox);
   mParameters->setReadOnly(true);
   boxLayout->addWidget( mParameters, 4, 1 );
-
-  lab = new QLabel( i18n("HINT: Delimiter=; Name=%1,Email=%2"), mExternalAppGroupBox);
-  boxLayout->addMultiCellWidget( lab, 5, 5, 0, 1 );
+      lab = new QLabel( i18n("HINT: Delimiter=; Name=%1,Email=%2"), mExternalAppGroupBox);
+      boxLayout->addMultiCellWidget( lab, 5, 5, 0, 1 );
 
 
-  lab = new QLabel( i18n("extra Message:"), mExternalAppGroupBox);
-  boxLayout->addWidget( lab, 6, 0 );
-  mMessage2 = new QLineEdit(mExternalAppGroupBox);
-  mMessage2->setReadOnly(true);
-  boxLayout->addWidget( mMessage2 , 7, 0);
+  if (  QApplication::desktop()->height() > 240 ) {
+      lab = new QLabel( i18n("extra Message:"), mExternalAppGroupBox);
+      boxLayout->addWidget( lab, 6, 0 );
+      mMessage2 = new QLineEdit(mExternalAppGroupBox);
+      mMessage2->setReadOnly(true);
+      boxLayout->addWidget( mMessage2 , 7, 0);
 
-  lab = new QLabel( i18n("extra Parameters:"), mExternalAppGroupBox);
-  boxLayout->addWidget( lab, 6, 1 );
-  mParameters2 = new QLineEdit(mExternalAppGroupBox);
-  mParameters2->setReadOnly(true);
-  boxLayout->addWidget( mParameters2, 7, 1 );
-
-  lab = new QLabel( i18n("HINT: Emails=%1,Attachments=%2"), mExternalAppGroupBox);
-  boxLayout->addMultiCellWidget( lab, 8, 8, 0, 1 );
+      lab = new QLabel( i18n("extra Parameters:"), mExternalAppGroupBox);
+      boxLayout->addWidget( lab, 6, 1 );
+      mParameters2 = new QLineEdit(mExternalAppGroupBox);
+      mParameters2->setReadOnly(true);
+      boxLayout->addWidget( mParameters2, 7, 1 );
 
+      lab = new QLabel( i18n("HINT: Emails=%1,Attachments=%2"), mExternalAppGroupBox);
+      boxLayout->addMultiCellWidget( lab, 8, 8, 0, 1 );
+      connect( mMessage2, SIGNAL( textChanged ( const QString & )), this, SLOT( textChanged ( const QString & ))  );
+      connect( mParameters2, SIGNAL( textChanged ( const QString & )), this, SLOT( textChanged ( const QString & ))  );
+  } else {
+      mMessage2 = 0;
+      mParameters2 = 0;
+  }
 
   connect( mChannel, SIGNAL( textChanged ( const QString & )), this, SLOT( textChanged ( const QString & ))  );
   connect( mMessage, SIGNAL( textChanged ( const QString & )), this, SLOT( textChanged ( const QString & ))  );
   connect( mParameters, SIGNAL( textChanged ( const QString & )), this, SLOT( textChanged ( const QString & ))  );
-  connect( mMessage2, SIGNAL( textChanged ( const QString & )), this, SLOT( textChanged ( const QString & ))  );
-  connect( mParameters2, SIGNAL( textChanged ( const QString & )), this, SLOT( textChanged ( const QString & ))  );
 
 
   layout->addWidget( mExternalAppGroupBox );
@@ -374,12 +399,15 @@ void KDEPIMConfigWidget::setupLocaleDateTab()
    lab = new QLabel( i18n("Monday 19 April 2004: %A %d %B %Y"), topFrame);
    topLayout->addMultiCellWidget(lab ,iii,iii,0,1);
    ++iii;
-   lab = new QLabel( i18n("Mon 19.04.04: %a %d.%m.%y"), topFrame);
-   topLayout->addMultiCellWidget(lab ,iii,iii,0,1);
-   ++iii;  
-   lab = new QLabel( i18n("Mon, 19.Apr.04: %a, %d.%b.%y"), topFrame);
-   topLayout->addMultiCellWidget(lab ,iii,iii,0,1);
-   ++iii;
+   //qDebug(" QApplication::desktop()->height()xx %d ",  QApplication::desktop()->height() ); 
+   if (  QApplication::desktop()->height() > 240 ) {
+       lab = new QLabel( i18n("Mon 19.04.04: %a %d.%m.%y"), topFrame);
+       topLayout->addMultiCellWidget(lab ,iii,iii,0,1);
+       ++iii;  
+       lab = new QLabel( i18n("Mon, 19.Apr.04: %a, %d.%b.%y"), topFrame);
+       topLayout->addMultiCellWidget(lab ,iii,iii,0,1);
+       ++iii;
+   }
 
   connect( mUserDateFormatLong, SIGNAL( textChanged ( const QString & )), this, SLOT( textChanged ( const QString & ))  );
   connect( mUserDateFormatShort, SIGNAL( textChanged ( const QString & )), this, SLOT( textChanged ( const QString & ))  );
@@ -628,8 +656,10 @@ void KDEPIMConfigWidget::saveEditFieldSettings()
     mEmailOtherChannel = mChannel->text();
     mEmailOtherMessage = mMessage->text();
     mEmailOtherMessageParameters = mParameters->text();
-    mEmailOtherMessage2 = mMessage2->text();
-    mEmailOtherMessageParameters2 = mParameters2->text();
+    if ( mMessage2 )
+        mEmailOtherMessage2 = mMessage2->text();   
+    if ( mParameters2 )
+        mEmailOtherMessageParameters2 = mParameters2->text();
   }
   else if ((mCurrentApp == ExternalAppHandler::PHONE) && (mCurrentClient == KPimGlobalPrefs::OTHER_PHC))
   {
@@ -693,8 +723,10 @@ void KDEPIMConfigWidget::updateClientWidgets()
       //Otherwise take the default data from externalapphandler.
       mChannel->setText(dai->_channel);
       mMessage->setText(dai->_message);
-      mParameters->setText(dai->_parameters);
-      mMessage2->setText(dai->_message2);
+      mParameters->setText(dai->_parameters);  
+      if ( mMessage2 )
+          mMessage2->setText(dai->_message2); 
+    if ( mParameters2 )
       mParameters2->setText(dai->_parameters2);
 
 
@@ -702,8 +734,10 @@ void KDEPIMConfigWidget::updateClientWidgets()
       {
         mChannel->setText(mEmailOtherChannel);
         mMessage->setText(mEmailOtherMessage);
-        mParameters->setText(mEmailOtherMessageParameters);
+        mParameters->setText(mEmailOtherMessageParameters); 
+        if ( mMessage2 )
         mMessage2->setText(mEmailOtherMessage2);
+    if ( mParameters2 )
         mParameters2->setText(mEmailOtherMessageParameters2);
       }
       else if ((mCurrentApp == ExternalAppHandler::PHONE) && (mCurrentClient == KPimGlobalPrefs::OTHER_PHC))
@@ -773,14 +807,18 @@ void KDEPIMConfigWidget::updateClientWidgets()
 
   mChannel->setReadOnly(readonly);
   mMessage->setReadOnly(readonly);
-  mParameters->setReadOnly(readonly);
+  mParameters->setReadOnly(readonly); 
+  if ( mMessage2 )
   mMessage2->setReadOnly(readonly);
+    if ( mParameters2 )
   mParameters2->setReadOnly(readonly);
 
   mChannel->setEnabled(enabled);
   mMessage->setEnabled(enabled);
   mParameters->setEnabled(enabled);
+  if ( mMessage2 )
   mMessage2->setEnabled(enabled);
+    if ( mParameters2 )
   mParameters2->setEnabled(enabled);
 
 
@@ -794,12 +832,16 @@ void KDEPIMConfigWidget::updateClientWidgets()
   }
   else
   {
+  if ( mMessage2 )
     mMessage2->setText( "" );
+    if ( mParameters2 )
     mParameters2->setText( "" );
   }
 
   if (enabled == true) {
+  if ( mMessage2 )
     mMessage2->setEnabled(mCurrentApp == ExternalAppHandler::EMAIL);
+    if ( mParameters2 )
     mParameters2->setEnabled(mCurrentApp == ExternalAppHandler::EMAIL);
   }
 
@@ -817,8 +859,10 @@ void KDEPIMConfigWidget::usrReadConfig()
 
   if (KPimGlobalPrefs::instance()->mBackupUseDefaultDir )
       mBackupUrl->setURL( KGlobalSettings::backupDataDir() );
-  else
+  else {
       mBackupUrl->setURL(prefs->mBackupDatadir);
+
+  }
   mBackupNumbersSpin->setValue( prefs->mBackupNumbers );
   mBackupDayCountSpin->setValue( prefs->mBackupDayCount);
 
