@@ -18,7 +18,7 @@
   Boston, MA 02111-1307, USA.
 */
 
-// $Id: ksyncmanager.cpp,v 1.57 2005/07/08 23:55:56 zautrix Exp $
+// $Id: ksyncmanager.cpp,v 1.58 2005/07/29 10:15:48 zautrix Exp $
 
 #include "ksyncmanager.h"
 
@@ -1566,11 +1566,17 @@ void KCommandSocket::writeFileToSocket()
     QTextStream os2( mSocket );
     os2.setEncoding( QTextStream::Latin1 );
     os2 << "PUT " << mPassWord << "\r\n\r\n";;
+    int byteCount = 0;
+    int byteMax = file2.size()/53;
     while ( ! ts2.atEnd() ) {
         qApp->processEvents();
-        mConnectProgress.setProgress( count );
+        if ( byteCount > byteMax ) {
+            byteCount = 0;
+            mConnectProgress.setProgress( count );
+        }
         QString temp = ts2.readLine();
         count += temp.length();
+        byteCount += temp.length();
         os2 << temp << "\r\n";
     }
     file2.close();
