@@ -476,7 +476,16 @@ bool KListView::isExecuteArea( const QPoint& point )
 
   return false;
 }
+QSize KListView::sizeHint() const
+{
+    //qDebug("KListView::QSize sizeHint() ");
+#ifdef DESKTOP_VERSION
+    return QListView::sizeHint();
+#else
+    return QSize ( 40, 40 );
+#endif
 
+}
 bool KListView::isExecuteArea( int x )
 {
   if( allColumnsShowFocus() )
