@@ -156,10 +156,24 @@ OFileSelectorItem::OFileSelectorItem( QListView* view, const QPixmap& pixmap,
                                       bool isLocked, bool isDir )
     : QListViewItem( view )
 {
+
+    QString kind = "dir";;
+    QString _path = path;
+    if ( !isDir ){
+        int arrow = path.findRev( "." ,-1); 
+        if (arrow > 0 ) {
+            kind = path.mid(arrow+1);
+        } 
+    }
     setPixmap(0, pixmap );
-    setText(1, path );
+    int arrow = path.find( "->" );
+    if (arrow > 0 ) {
+        _path = path.left(arrow);
+    } 
+    setText(1, _path );
     setText(2, size );
     setText(3, date );
+    setText(4, kind );
     m_isDir = isDir;
     m_dir = dir;
     m_locked = isLocked;
@@ -190,7 +204,12 @@ QString OFileSelectorItem::key( int id, bool )const {
             ke.append( text(1) );
         }
         return ke;
-    }else
+    } else if ( id == 2 ) {
+        QString sort = "00000000";
+        sort = sort.left( 9-text( 2 ).length()) +  text( 2 );
+        return sort;
+
+    } else 
         return text( id );
 
 }
@@ -273,9 +292,9 @@ OFileViewFileListView::OFileViewFileListView( QWidget* parent, const QString& st
     QPEApplication::setStylusOperation( m_view->viewport(),
                                         QPEApplication::RightOnHold);
     m_view->addColumn(" " );
-    m_view->addColumn(i18n("Name"), 135 );
+    m_view->addColumn(i18n("Name"), 150 );
     m_view->addColumn(i18n("Size"), -1 );
-    m_view->addColumn(i18n("Date"), 60 );
+    m_view->addColumn(i18n("Date"), -1 );
     m_view->addColumn(i18n("Mime Type"), -1 );
 
 
@@ -345,9 +364,11 @@ void OFileViewFileListView::reread( bool all ) {
        *
        */
       if( fi->isSymLink() ){
-          QString file = fi->dirPath( true ) + "/" + fi->readLink();
-          for( int i = 0; i<=4; i++) { // 5 tries to prevent dos
+          //qDebug("SYMLINK ");
+          QString file = fi->readLink();
+          for( int i = 0; i<=5; i++) { // 5 tries to prevent dos
               QFileInfo info( file );
+              //qDebug("FILE %s ", file.latin1());
               if( !info.exists() ){
                   addSymlink( fi, TRUE );
                   break;
@@ -358,7 +379,7 @@ void OFileViewFileListView::reread( bool all ) {
                   addFile( fi, TRUE );
                   break;
               }else if( info.isSymLink() ){
-                  file = info.dirPath(true ) + "/" + info.readLink() ;
+                  file = info.readLink() ;
                   break;
               }else if( i == 4){ // couldn't resolve symlink add it as symlink
                   addSymlink( fi );
@@ -486,7 +507,7 @@ void OFileViewFileListView::addFile( QFileInfo* info, bool symlink ) {
     dir = info->dirPath( true );
     locked = false;
     if ( symlink )
-        name = info->fileName() + " -> " + info->dirPath() + "/" + info->readLink();
+        name = info->fileName() + " -> " + info->readLink();
     else{
         name = info->fileName();
         if ( ( (selector()->mode() == OFileSelector::Open)&& !info->isReadable() ) ||
@@ -512,7 +533,7 @@ void OFileViewFileListView::addDir( QFileInfo* info, bool symlink ) {
     }else
         pix = symlink ? Resource::loadPixmap( "symlink") : Resource::loadPixmap("folder");
 
-    name = symlink ? info->fileName() + " -> " + info->dirPath(true) + "/" + info->readLink() :
+    name = symlink ? info->fileName() + " -> "  + info->readLink() :
            info->fileName();
 
     (void)new OFileSelectorItem( m_view, pix, name,
